@@ -12,21 +12,48 @@ from .lib.installer import __packages__, Installer, accessibility_tools_in_use
 from .lib.locale_helpers import *
 from .lib.luks import *
 from .lib.mirrors import *
+from .lib.models.network_configuration import NetworkConfigurationHandler
 from .lib.networking import *
 from .lib.output import *
-from .lib.packages import *
+from .lib.models.dataclasses import (
+	VersionDef,
+	PackageSearchResult,
+	PackageSearch,
+	LocalPackage
+)
+from .lib.packages.packages import (
+	group_search,
+	package_search,
+	find_package,
+	find_packages,
+	installed_package,
+	validate_package_list,
+)
 from .lib.profiles import *
 from .lib.services import *
 from .lib.storage import *
 from .lib.systemd import *
 from .lib.user_interaction import *
+from .lib.menu import Menu
+from .lib.menu.list_manager import ListManager
+from .lib.menu.text_input import TextInput
+from .lib.menu.global_menu import GlobalMenu
+from .lib.menu.selection_menu import (
+	Selector,
+	GeneralMenu
+)
+from .lib.translation import Translation, DeferredTranslation
 from .lib.plugins import plugins, load_plugin # This initiates the plugin loading ceremony
-
+from .lib.configuration import *
 parser = ArgumentParser()
 
-__version__ = "2.3.3"
+__version__ = "2.4.1"
 storage['__version__'] = __version__
 
+# add the custome _ as a builtin, it can now be used anywhere in the
+# project to mark strings as translatable with _('translate me')
+DeferredTranslation.install()
+
 
 def define_arguments():
 	"""
@@ -42,12 +69,12 @@ def define_arguments():
 					help="JSON disk layout file")
 	parser.add_argument("--silent", action="store_true",
 						help="WARNING: Disables all prompts for input and confirmation. If no configuration is provided, this is ignored")
-	parser.add_argument("--dry-run","--dry_run",action="store_true",
+	parser.add_argument("--dry-run", "--dry_run", action="store_true",
 						help="Generates a configuration file and then exits instead of performing an installation")
 	parser.add_argument("--script", default="guided", nargs="?", help="Script to run for installation", type=str)
-	parser.add_argument("--mount-point","--mount_point",nargs="?",type=str,help="Define an alternate mount point for installation")
-	parser.add_argument("--debug",action="store_true",help="Adds debug info into the log")
-	parser.add_argument("--plugin",nargs="?",type=str)
+	parser.add_argument("--mount-point","--mount_point", nargs="?", type=str, help="Define an alternate mount point for installation")
+	parser.add_argument("--debug", action="store_true", default=False, help="Adds debug info into the log")
+	parser.add_argument("--plugin", nargs="?", type=str)
 
 def parse_unspecified_argument_list(unknowns :list, multiple :bool = False, error :bool = False) -> dict:
 	"""We accept arguments not defined to the parser. (arguments "ad hoc").
@@ -99,7 +126,7 @@ def parse_unspecified_argument_list(unknowns :list, multiple :bool = False, erro
 					print(f" We ignore the entry {element} as it isn't related to any argument")
 	return config
 
-def get_arguments():
+def get_arguments() -> Dict[str, Any]:
 	""" The handling of parameters from the command line
 	Is done on following steps:
 	0) we create a dict to store the arguments and their values
@@ -149,22 +176,71 @@ def get_arguments():
 		del config['dry-run']
 	return config
 
+def load_config():
+	from .lib.models import NetworkConfiguration
+	"""
+	refine and set some arguments. Formerly at the scripts
+	"""
+	if arguments.get('harddrives', None) is not None:
+		if type(arguments['harddrives']) is str:
+			arguments['harddrives'] = arguments['harddrives'].split(',')
+		arguments['harddrives'] = [BlockDevice(BlockDev) for BlockDev in arguments['harddrives']]
+		# Temporarily disabling keep_partitions if config file is loaded
+		# Temporary workaround to make Desktop Environments work
+	if arguments.get('profile', None) is not None:
+		if type(arguments.get('profile', None)) is dict:
+			arguments['profile'] = Profile(None, arguments.get('profile', None)['path'])
+		else:
+			arguments['profile'] = Profile(None, arguments.get('profile', None))
+	storage['_desktop_profile'] = arguments.get('desktop-environment', None)
+	if arguments.get('mirror-region', None) is not None:
+		if type(arguments.get('mirror-region', None)) is dict:
+			arguments['mirror-region'] = arguments.get('mirror-region', None)
+		else:
+			selected_region = arguments.get('mirror-region', None)
+			arguments['mirror-region'] = {selected_region: list_mirrors()[selected_region]}
+	if arguments.get('sys-language', None) is not None:
+		arguments['sys-language'] = arguments.get('sys-language', 'en_US')
+	if arguments.get('sys-encoding', None) is not None:
+		arguments['sys-encoding'] = arguments.get('sys-encoding', 'utf-8')
+	if arguments.get('gfx_driver', None) is not None:
+		storage['gfx_driver_packages'] = AVAILABLE_GFX_DRIVERS.get(arguments.get('gfx_driver', None), None)
+	if arguments.get('servers', None) is not None:
+		storage['_selected_servers'] = arguments.get('servers', None)
+	if arguments.get('nic', None) is not None:
+		handler = NetworkConfigurationHandler()
+		handler.parse_arguments(arguments.get('nic'))
+		arguments['nic'] = handler.configuration
+
 def post_process_arguments(arguments):
 	storage['arguments'] = arguments
 	if arguments.get('mount_point'):
 		storage['MOUNT_POINT'] = arguments['mount_point']
 
-	if arguments.get('debug',False):
+	if arguments.get('debug', False):
 		log(f"Warning: --debug mode will write certain credentials to {storage['LOG_PATH']}/{storage['LOG_FILE']}!", fg="red", level=logging.WARNING)
 
 	if arguments.get('plugin', None):
 		load_plugin(arguments['plugin'])
 
 	if arguments.get('disk_layouts', None) is not None:
-		if 'disk_layouts' not in storage:
-			storage['disk_layouts'] = {}
-		if not json_stream_to_structure('--disk_layouts',arguments['disk_layouts'],storage['disk_layouts']):
+		# if 'disk_layouts' not in storage:
+		# 	storage['disk_layouts'] = {}
+		layout_storage = {}
+		if not json_stream_to_structure('--disk_layouts',arguments['disk_layouts'],layout_storage):
 			exit(1)
+		else:
+			if arguments.get('harddrives') is None:
+				arguments['harddrives'] = [disk for disk in layout_storage]
+			# backward compatibility. Change partition.format for partition.wipe
+			for disk in layout_storage:
+				for i,partition in enumerate(layout_storage[disk].get('partitions',[])):
+					if 'format' in partition:
+						partition['wipe'] = partition['format']
+						del partition['format']
+			arguments['disk_layouts'] = layout_storage
+
+	load_config()
 
 
 define_arguments()
@@ -176,6 +252,7 @@ post_process_arguments(arguments)
 def plugin(f, *args, **kwargs):
 	plugins[f.__name__] = f
 
+
 def run_as_a_module():
 	"""
 	Since we're running this as a 'python -m archinstall' module OR
